RlineError

Enum RlineError 

pub enum RlineError {
    ConfigurationError(String),
    RuntimeError(String),
    TooManyFailsError(usize),
    BadTypeError(String),
}
Represents any error that may occur during rline initialization and running.

Variants



ConfigurationError(String)

This exception is probably the most crucial rline error. It is thrown whenever a required property is missing, or if a mismatch in your configuration like invalid dag. You may have a typo somewhere.



RuntimeError(String)

A RuntimeError is raised whenever a connector encounters an error. Typically an I/O or connection error. It is of highest importance to raise a useful error message to the user, and to keep the error trace when available.



TooManyFailsError(usize)

A TooManyFailsError thrown whenever the exit condition of number of failing rows is reached.



BadTypeError(String)

A RuntimeError is raised whenever you try to cast a Value to a bad type.

Implementations

Source

impl RlineError

pub fn runtime_error(cause: &dyn Error) -> Self

Returns a new RuntimeError keeping the trace of the causing error.

pub fn configuration_error(cause: &dyn Error) -> Self

Returns a new ConfigurationError keeping the trace of the causing error.